# generated by datamodel-codegen:
#   filename:  publication_schema.json
#   timestamp: 2024-02-07T14:07:20+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional

from pydantic import BaseModel, Extra, Field

from . import comment_schema, ontology_annotation_schema


class FieldType(Enum):
    Publication = 'Publication'


class ISAPublicationSchema(BaseModel):
    class Config:
        extra = Extra.forbid

    field_id: Optional[str] = Field(None, alias='@id')
    field_context: Optional[str] = Field(None, alias='@context')
    field_type: Optional[FieldType] = Field(None, alias='@type')
    pubMedID: Optional[str] = None
    doi: Optional[str] = None
    authorList: Optional[str] = None
    title: Optional[str] = None
    status: Optional[ontology_annotation_schema.ISAOntologyReferenceSchema] = None
    comments: Optional[List[comment_schema.ISACommentSchema]] = None
